#
# spec file for package perl-User-Identity
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name User-Identity
Name:           perl-User-Identity
Version:        1.02
Release:        1.4
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Collect information about a user
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MARKOV/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Hash::Ordered) >= 0.014
Requires:       perl(Hash::Ordered) >= 0.014
%{perl_requires}

%description
The 'User-Identity' distribution is created to maintain a set of
informational objects which are related to one user. The 'User::Identity'
module tries to be smart providing defaults, conversions and often required
combinations.

The identities are not implementing any kind of storage, and can therefore
be created by any simple or complex Perl program. This way, it is more
flexible than an XML file to store the data. For instance, you can decide
to store the data with Data::Dumper, Storable, DBI, AddressBook or
whatever. Extension to simplify this task are still to be developed.

If you need more kinds of user information, then please contact the module
author.

Extends "DESCRIPTION" in User::Identity::Item.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc ChangeLog README README.md

%changelog
* Tue Apr 18 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.02
  see /usr/share/doc/packages/perl-User-Identity/ChangeLog
  version 1.02: Mon 17 Apr 10:40:50 CEST 2023
  Changes:
  - Collections use ordered hash to generate reproducable
  results.  Github issue 15 on Mail::Message [Geoffrey D. Bennett]
* Sat Feb 12 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.01
  see /usr/share/doc/packages/perl-User-Identity/ChangeLog
  version 1.01: Fri 11 Feb 11:25:41 CET 2022
  Fixes:
  - Coercion from Mail::Address to Mail::Message::Full::Address is
  too lazy. Mail::Message issue #4
* Thu Oct 15 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.00
  see /usr/share/doc/packages/perl-User-Identity/ChangeLog
  version 1.00: Wed 14 Oct 19:14:36 CEST 2020
  Fixes:
  - fix metadata [Mohammad S Anwar]
  - when the username of an address contains " [Andy Beverley]
* Wed Feb  7 2018 coolo@suse.com
- updated to 0.99
  see /usr/share/doc/packages/perl-User-Identity/Changes
* Thu Nov  9 2017 coolo@suse.com
- updated to 0.98
  see /usr/share/doc/packages/perl-User-Identity/Changes
* Tue Feb 14 2017 coolo@suse.com
- updated to 0.97
  see /usr/share/doc/packages/perl-User-Identity/Changes
  version 0.97: Thu  2 Feb 15:52:27 CET 2017
  Improvements:
  - spell checks from Debian.
  rt.cpan.org#118328 [Angel Abad]
  - share podtail with MailBox
* Thu Sep 22 2016 coolo@suse.com
- updated to 0.96
  see /usr/share/doc/packages/perl-User-Identity/Changes
  version 0.96: Mon Sep 19 23:15:07 CEST 2016
  Fixes:
  - include examples in the manual-pages
  version 0.95:
  Improvements:
  - move t/99pod.t to xt/ and remove dependency on Test::Pod
  - spell checks from Debian.
  rt.cpan.org#92483 [Salvatore Bonaccorso]
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.94
  see /usr/share/doc/packages/perl-User-Identity/Changes
  version 0.94: Fri Jan 24 10:55:26 CET 2014
  Improvements:
  - changed documentation style
* Fri Nov 18 2011 coolo@suse.com
- use tar.gz
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Apr  2 2010 chris@computersalat.de
- update to version 0.93
  o Fixes:
  - Mail::Identity->from(Mail::Address) produced error
    rt.cpan.org#52115 [Dmitry Bigunyak]
  o Improvements:
  - do not run t/pod.t in devel environment.
- version 0.92: Wed Jul 25 08:50:51 CEST 2007
  o Improvements:
  - add t/pod.t and distribution clean-ups.
- spec mods
  o fixed HEADER
  o sort TAGS
  o fixed deps
  o macros
  o updated description
  o changelog to changes file
* Fri Oct 31 2008 rbos@opensuse.org
- fixed rpmlint errorsj
- new upstream version 0.91
- fixed BuildRequires
